==> agent-java-0.0.3-sources.jar: dev/shortloop/agent/config/AgentConfigUtils.java <==
package dev.shortloop.agent.config;

import dev.shortloop.common.models.data.*;
import org.apache.commons.lang3.StringUtils;

public class AgentConfigUtils {
    public static boolean isConfigValid(AgentConfig agentConfig) {
        if (null == agentConfig) {
            return false;
        }
        if (null == agentConfig.getBufferSyncFreqInSec()) {
            return false;
        }
        if (null == agentConfig.getConfigFetchFreqInSec()) {
            return false;
        }
        if (null == agentConfig.getCaptureApiSample()) {
            return false;
        }
        if (null == agentConfig.getDiscoveryBufferSize()) {
            return false;
        }
        if (null == agentConfig.getDiscoveryBufferSizePerApi()) {
            return false;
        }
        if (null != agentConfig.getRegisteredApiConfigs()) {
            for (AgentConfig.ApiConfig apiConfig : agentConfig.getRegisteredApiConfigs()) {
                if (!isApiConfigValid(apiConfig)) {
                    return false;
                }
            }
        }
        return true;
    }

    static boolean isApiConfigValid(AgentConfig.ApiConfig apiConfig) {
        if (null == apiConfig) {
            return false;
        }
        if (!isURIValid(apiConfig.getUri())) {
            return false;
        }
        if (null == apiConfig.getMethod()) {
            return false;
        }
        if (null == apiConfig.getBufferSize()) {
            return false;
        }
        if (null == apiConfig.getCaptureSample()) {
            return false;
        }
        return true;
    }

    static boolean isURIValid(URI uri) {
        if (null == uri) {
            return false;
        }
        if (StringUtils.isEmpty(uri.getUriPath())) {
            return false;
        }
        return true;
    }


    static boolean isDataSizeValid(DataSize dataSize) {
        if (null == dataSize) {
            return false;
        }
        return dataSize.getDataValue() >= 0 && dataSize.getDataUnit() != null;
    }

    static boolean isPeriodValid(Period period) {
        if (null == period) {
            return false;
        }
        return period.getTimeValue() >= 0 && period.getTimeUnit() != null;
    }
}

==> agent-java-0.0.4-sources.jar: dev/shortloop/agent/config/AgentConfigUtils.java <==
package dev.shortloop.agent.config;

import dev.shortloop.common.models.data.*;

public class AgentConfigUtils {
    public static boolean isConfigValid(AgentConfig agentConfig) {
        if (null == agentConfig) {
            return false;
        }
        if (null == agentConfig.getBufferSyncFreqInSec()) {
            return false;
        }
        if (null == agentConfig.getConfigFetchFreqInSec()) {
            return false;
        }
        if (null == agentConfig.getCaptureApiSample()) {
            return false;
        }
        if (null == agentConfig.getDiscoveryBufferSize()) {
            return false;
        }
        if (null == agentConfig.getDiscoveryBufferSizePerApi()) {
            return false;
        }
        if (null != agentConfig.getRegisteredApiConfigs()) {
            for (AgentConfig.ApiConfig apiConfig : agentConfig.getRegisteredApiConfigs()) {
                if (!isApiConfigValid(apiConfig)) {
                    return false;
                }
            }
        }
        return true;
    }

    static boolean isApiConfigValid(AgentConfig.ApiConfig apiConfig) {
        if (null == apiConfig) {
            return false;
        }
        if (!isURIValid(apiConfig.getUri())) {
            return false;
        }
        if (null == apiConfig.getMethod()) {
            return false;
        }
        if (null == apiConfig.getBufferSize()) {
            return false;
        }
        if (null == apiConfig.getCaptureSample()) {
            return false;
        }
        return true;
    }

    static boolean isURIValid(URI uri) {
        if (null == uri) {
            return false;
        }
        if (null == uri.getUriPath() || uri.getUriPath().length() == 0) {
            return false;
        }
        return true;
    }


    static boolean isDataSizeValid(DataSize dataSize) {
        if (null == dataSize) {
            return false;
        }
        return dataSize.getDataValue() >= 0 && dataSize.getDataUnit() != null;
    }

    static boolean isPeriodValid(Period period) {
        if (null == period) {
            return false;
        }
        return period.getTimeValue() >= 0 && period.getTimeUnit() != null;
    }
}
